```
data {
    int<lower=1> N; //number of data points
    real ibi[N]; //IBI value

    int<lower=1> L; //number of subjects
    int<lower=1, upper=L> subj[N]; //subject id for each data point

    int<lower=1> J; //number of roles
    int<lower=1, upper=J> role[N]; //role id for each data point

    int<lower=1> K; //number of tasks
    int<lower=1, upper=K> task[N]; //task id for each data point
}

parameters {

    //fixed intercept for location
    real beta;

    // role effect on location
    real r_tilde[J]; //re-parametrization of r
    real<lower=0> sigma_r; //sd of r

    // task effect on location
    real w_tilde[K]; //re-parametrization of w
    real<lower=0> sigma_w; //sd of w


    // fixed effect for scale (residual variance)
    real<lower=0> sigma_e; //error sd

    // task effect on scale
    real sd_w_tilde[K]; //re-parametrization of sd_w
    real<lower=0> sigma_sd_w; //sd of sd_w

    // subject effect on scale
    real sd_sbj_tilde[L]; //re-parametrization of sd_sbj
    real<lower=0> sigma_sd_sbj; //sd of sd_sbj
}

transformed parameters {

  // Define transformed parameters
  vector[J] r; //role effects on mean
  vector[K] w; //task effects on mean
  vector[P] rt; // role-task interaction effect on mean
  vector[K] sd_w; //task effects on sd
  vector[L] sd_sbj; //subject effects on sd

  // reparametrization of r
  for (j in 1:J){
    r[j] = sigma_r * r_tilde[j];
  }

  // reparametrization of w
  for (k in 1:K){
    w[k] = sigma_w * w_tilde[k];
  }


  // reparametrization of sd_w
  for (k in 1:K){
    sd_w[k] = sigma_sd_w * sd_w_tilde[k];
  }

  // reparametrization of sd_sbj
  for (l in 1:L){
    sd_sbj[l] = sigma_sd_sbj * sd_sbj_tilde[l];
  }
}

model {
    // priors
    beta ~ normal(0, 5);
    sigma_e ~ cauchy(0, 5);

    sigma_r ~ cauchy(0, 5);
    sigma_w ~ cauchy(0, 5);
    sigma_sd_w ~ cauchy(0, 5);
    sigma_sd_sbj ~ cauchy(0, 5);

    // Reparameterization
    // an attempt to make sampling more efficient:
    // see Stan manual or https://arxiv.org/abs/0708.3797
    r_tilde ~ normal(0, 1); // implies r ~ normal(0, sigma_r)
    w_tilde ~ normal(0, 1); // implies w ~ normal(0, sigma_w)
    sd_w_tilde ~ normal(0, 1); // implies sd_w ~ normal(0, sigma_sd_w)
    sd_sbj_tilde ~ normal(0, 1); // implies sd_sbj ~ normal(0, sigma_sd_sbj)

    // sampling distribution
    for (i in 1:N){
        ibi[i] ~ normal(beta + r[role[i]] + w[task[i]] + rt[roletask[i]],
                        sigma_e + sd_w[task[i]] + sd_sbj[subj[i]]);
    }
}
```